###################################################
### chunk number 1: 
###################################################
options(continue="   ")
options(width=95)


###################################################
### chunk number 2: 
###################################################
library(SDisc)


###################################################
### chunk number 3: dataMixt3
###################################################
set.seed(6014)
mixt3 <- matrix(c(rnorm(50), rnorm(50,mean=3,sd=5), rnorm(50,mean=-2,sd=4)), 50, 3)


###################################################
### chunk number 4: dataNormdep
###################################################
set.seed(6015)
epsilon <- runif(50)
time <- sample(1:5, 50, replace=TRUE)
vDependent <- 2*time+epsilon 
normdep <- matrix(c(rnorm(50), time, epsilon, vDependent, vDependent), 50, 5)
colnames(normdep) <- c("vNormal","time","epsilon","vDependentOrig", "vDependent")


###################################################
### chunk number 5: dataIris eval=FALSE
###################################################
## library(datasets)
## help('iris')


###################################################
### chunk number 6: dataState
###################################################
state.loc <- read.csv("state.latlon.csv", row.names=1)
state <- data.frame(state.x77[,hclust(dist(t(state.x77)))$order], name=row.names(state.x77), latitude=NA,
   longitude=NA)
row.names(state) <- state.abb
naRows <- row.names(state.loc)[(!row.names(state.loc) %in% row.names(state))]
state <- rbind(state,matrix(NA,length(naRows),ncol(state),dimnames=list(naRows, colnames(state))))
state[,c('latitude','longitude')] <- state.loc[row.names(state),c('latitude','longitude')]


###################################################
### chunk number 7: dataOrchardSpraysHelp eval=FALSE
###################################################
## help('OrchardSprays')


###################################################
### chunk number 8: dataOsprays
###################################################
osprays <- OrchardSprays


###################################################
### chunk number 9: settingsMixt3
###################################################
settingsMixt3 <- SDDataSettings(mixt3)


###################################################
### chunk number 10: settingsNormdep
###################################################
settingsNormdep <- SDDataSettings(normdep)
settingsNormdep[,'tFun'] <- c('mean sd','', '','', 'lm(vDependent~time)')


###################################################
### chunk number 11: settingsIris
###################################################
SDDataSettings(iris, latex=TRUE)
SDDataSettings(iris, asCSV=TRUE)
SDDataSettings(iris, asCSV='irisSettings.csv')
settingsIris <- SDDataSettings(iris)
settingsIris['Species',] <- c(NA,FALSE, NA, NA, NA,NA)


###################################################
### chunk number 12: settingsState
###################################################
settingsState <- SDDataSettings(state, asCSV='stateSettings.csv')
settingsState <- read.csv2('stateSettingsEdited.csv', row.names=1)


###################################################
### chunk number 13: settingsOsprays
###################################################
settingsOsprays <- SDDataSettings(osprays)
settingsOsprays['treatment',] <- NA


###################################################
### chunk number 14: SDData
###################################################
dMixt3 <- SDData(mixt3, settings=settingsMixt3, prefix='Mixt3')
dNormdep <- SDData(normdep, settings=settingsNormdep, prefix='Normdep')
dState <- SDData(state, settings=settingsState, prefix='state')


###################################################
### chunk number 15: SDDataEDA
###################################################
print(dMixt3, rseed=6013, latex=TRUE)
plot(dMixt3, latex=TRUE)
summary(dMixt3, latex=TRUE)
print(dNormdep, rseed=6013, latex=TRUE)
plot(dNormdep, latex=TRUE)
summary(dNormdep, q='lm', latex=TRUE, sanitize=FALSE)
summary(dNormdep, q='mean|sd', latex=TRUE)
naPattern(dState, latex=TRUE)


###################################################
### chunk number 16: SDDataPredictLatex
###################################################
set.seed(6016)
epsilon <- runif(30)
time <- sample(1:5, 30, replace=TRUE)
vDependent <- 2*time+epsilon 
mat <- matrix(c(rnorm(30), time, epsilon, vDependent, vDependent), 30, 5)
colnames(mat) <- c("vNormal","time","epsilon","vDependentOrig","vDependent")
dNormdepPredicted <- predict(dNormdep, newdata=mat, prefix='NormdepPredicted')
summary(dNormdepPredicted, q='lm', latex=TRUE, sanitize=FALSE)
summary(dNormdepPredicted, q='mean|sd', latex=TRUE)


###################################################
### chunk number 17: SDisc
###################################################
xNormdep <- SDisc(dNormdep)
xState <- SDisc(state, settings=settingsState, prefix='state', cFunSettings=list(modelName=c("EII", "VII",
"VEI","VVI"), G=3:5, rseed=6013:6023))
xOsprays <- SDisc(osprays, settings=settingsOsprays, prefix='osprays', cFunSettings=list(modelName=c("EII", "VII", 
"VEI"), G=3:6, rseed=6013:6023))


###################################################
### chunk number 18: SDiscBictable
###################################################
summary(bicTable(xNormdep), latex=TRUE)
summary(bicTable(xState), latex=TRUE)
print(bicTable(xState), modelName='VII', G=4, latex=TRUE)
summary(bicTable(xOsprays), latex=TRUE)


###################################################
### chunk number 19: SDiscCompare
###################################################
print(xNormdep, latex=TRUE)
print(xState, latex=TRUE)
print(xState, m1=1, m2=bestModel(xState, modelName='VII', G=4)[1], latex=TRUE)
print(xOsprays, latex=TRUE)


###################################################
### chunk number 20: SDiscCharacterize
###################################################
plot(xState, latex=TRUE)
plot(xOsprays, latex=TRUE)
summary(xState, q=1, latex=TRUE)
summary(xOsprays, q=1, latex=TRUE)


###################################################
### chunk number 21: SDiscValidate
###################################################
summary(xOsprays, type='chi2test', target='treatment', latex=TRUE)


###################################################
### chunk number 22: SDiscInstall eval=FALSE
###################################################
## install.packages('SDisc', dep=TRUE)


###################################################
### chunk number 23: SDiscLoadLibrary
###################################################
library(SDisc)


